(* ::Package:: *)

(* ::Section::Closed:: *)
(*About*)


(* ::Text:: *)
(*This notebook is composed of 4 parts :*)
(**)
(*1) Setup : Enables basic functionality for importing xml and shows some ways to access methods in the Spore API.*)
(*2) Rigblock Files : Shows some ways to gather data about a creature such as the position and size of each part and the color that it is painted with.*)
(*3) Content :  View the distribution of content types and measure how often uploads are occuring at this moment.*)
(*4) Taxonomy :  Explores new ways to sort Spore creatures : such as by parts that they share in common, by a creature stat (such as meanness), by complexity, *)
(*by their color or by their geometric shape.*)
(*  *)
(*by Michael Twardos*)
(*mtwardos@maxis.com*)
(*3-26-2009*)


(* ::Section::Closed:: *)
(*Spore API Samples*)


(* ::Subsection::Closed:: *)
(*Setup*)


(* ::Subsubsection::Closed:: *)
(*General XML*)


getXML[url_]:=Quiet[Import[url, "XML"]];


getXMLdata[xml_, node_]:=Cases[xml, XMLElement[node,_,_], Infinity]


getXMLdata4[xml_, node_]:=Quiet[Cases[xml, XMLElement[node,_,_], Infinity][[1]][[3]][[1]]]


getXMLdata3[xml_, node_]:=Cases[Import[xml, "XML"], XMLElement[node,_,_], Infinity][[1]][[3]][[1]]


getXdat[xml_, node_]:=Cases[xml, XMLElement[node,_,_], 1][[1]][[3]]


getXdat2[xml_, node_]:=Cases[xml, XMLElement[node,_,_], 1][[1]][[3]][[1]]


getXMLarray[xml_, node_]:=Cases[, XMLElement[node,_,_], Infinity]


getXMLvalue[xml_, node_]:=Cases[xml, XMLElement[node,_,_], Infinity][[1]][[3]][[1]]


(* ::Subsubsection::Closed:: *)
(*Webservice Calls*)


getCRT[id_]:=Import[StringJoin["http://www.spore.com/static/model/",StringTake[id,{1,3}],"/",StringTake[id,{4,6}],"/",StringTake[id,{7,9}],"/",id,".xml"]]


getImage[id_]:=Import[StringJoin["http://www.spore.com/static/thumb/",StringTake[id,{1,3}],"/",StringTake[id,{4,6}],"/",StringTake[id,{7,9}],"/",id,".png"]]


getSporeAssets[view_, length_, type_]:=#[[3]]&/@getXMLdata[getXML[StringJoin["http://www.spore.com/rest/assets/search/",view,"/0/",length,"/",type]], "asset"]


getCreatureStats[id_]:=getXMLdata[getXML[StringJoin["http://www.spore.com/rest/creature/",id]], "creature"]


getCreatorAssets[user_, length_, type_]:=Flatten[(#[[3]]&/@getXMLdata[#, "id"])&/@getXMLdata[getXML[StringJoin["http://www.spore.com/rest/assets/user/",user, "/0/", length, "/", type]], "assets"]]


getAssetInfo[id_]:=getXML[StringJoin["http://www.spore.com/rest/asset/", id]]


getRandomList[type_, L_]:=Module[{lst={}},
For[i=1, i<= Round[L/20],
lst=Join[lst, getSporeAssets["RANDOM", "20", type]];
i++];
lst]


(* ::Subsection::Closed:: *)
(*Rigblock Files*)


(* ::Subsubsection::Closed:: *)
(*Rigblock Sample*)


myCreatures=getCreatorAssets["MaxisMichael", "9", "CREATURE"]


computeRules[vv_]:=Rule[ToExpression[vv[[1]]], ToExpression[#]]&/@vv[[2]]


make3Dmodel[id_]:=Module[{creaturefile, blocks, scale, childidCand, parents, vvv, vv, coors, spheres, l},
creaturefile=getCRT[id];
blocks=creaturefile[[2]][[3]][[3]][[3]];
scale=ToExpression[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="scale" &]&/@blocks)]];
childidCand=If[Length[#[[3]]]> 3,#[[3]][[4]][[3]], {"NONE"}] &/@blocks;
parents=Riffle[Range[0, Length[blocks]-1],Flatten[(If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand,1]];
vvv=Partition[Riffle[Range[0, Length[blocks]-1],Flatten[#]&/@((If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand)],2];
vv=Select[vvv, Not[MemberQ[#[[2]], "NONE"]]&];
coors=(If[StringCases[#,_~~"e"->"0"]=={"0"}, 0, ToExpression[#]]&/@#)&/@StringSplit[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="position" &]&/@blocks)],","];
spheres=Partition[Riffle[coors, scale],2];
l={coors[[#[[1]]+1]], coors[[#[[2]]+1]]}&/@Flatten[computeRules[#]&/@vv];
 Graphics3D[{ Red, Sphere[#[[1]], #[[2]]/20]&/@spheres, Blue, Thick, Line[#]&/@l}, Axes->True]]


TableForm[Partition[make3Dmodel[#]&/@myCreatures,4]]


(* ::Subsubsection::Closed:: *)
(*Color Example*)


myCreatures=getCreatorAssets["MaxisMichael", "9", "CREATURE"];


colorInfos={};
For[i=1, i<Length[myCreatures], 
a=getCRT[myCreatures[[i]]];
If[a[[2]][[3]][[2]][[3]][[1]][[3]] == {"0x9ea3031a"},colorInfos=Append[colorInfos, {myCreatures[[i]],#[[3]]&/@a[[2]][[3]][[2]][[3]][[8;;10]]}]];
i++]


TableForm[Partition[{getImage[#[[1]]],
Graphics[{First[RGBColor[#[[1]],#[[2]], #[[3]]]&/@ ToExpression[StringSplit[#[[2]][[1]], ","]]], 
Disk[{0,0},1],First[RGBColor[#[[1]],#[[2]], #[[3]]]&/@ToExpression[StringSplit[ #[[2]][[2]],","]]], 
Disk[{0,0},.6],First[RGBColor[#[[1]],#[[2]], #[[3]]]&/@ToExpression[StringSplit[#[[2]][[3]], ","]]], Disk[{0,0},.3]}]}&/@colorInfos,4]]


(* ::Subsection::Closed:: *)
(*Taxonomy*)


(* ::Subsubsection::Closed:: *)
(*Functions*)


rigblocks=Import["http://www.spore.com/data/blocks/creatureblockmap.xml", "Text"];


limblocks=Import["http://www.spore.com/data/blocks/limbblockmap.xml", "Text"];


importRigblockImage[name_]:=Import[StringJoin["http://www.spore.com/data/blocks/thumbs/", name,".png"], "Graphics"];


getCRT[id_]:=Import[StringJoin["http://www.spore.com/static/model/",StringTake[id,{1,3}],"/",StringTake[id,{4,6}],"/",StringTake[id,{7,9}],"/",id,".xml"]]


getImage[id_]:=Import[StringJoin["http://www.spore.com/static/thumb/",StringTake[id,{1,3}],"/",StringTake[id,{4,6}],"/",StringTake[id,{7,9}],"/",id,".png"]]


computeRules[vv_]:=Rule[ToExpression[vv[[1]]], ToExpression[#]]&/@vv[[2]]


makeNiceGuds[gd_]:=StringTake[#, {2,11}]&/@gd;


getGuids[id_]:=Module[{a, blocks, guids}, 
a=getCRT[id];
blocks=a[[2]][[3]][[3]][[3]];
guids=#[[1]][[2]]&/@(StringSplit[#, ","]&/@(#[[3]][[1]][[3]]&/@blocks))]


get3Dcoors[id_]:=Module[{creaturefile, blocks, scale, childidCand, parents, vvv, vv, coors, spheres, l},
creaturefile=getCRT[id];
blocks=creaturefile[[2]][[3]][[3]][[3]];
scale=ToExpression[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="scale" &]&/@blocks)]];
childidCand=If[Length[#[[3]]]> 3,#[[3]][[4]][[3]], {"NONE"}] &/@blocks;
parents=Riffle[Range[0, Length[blocks]-1],Flatten[(If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand,1]];
vvv=Partition[Riffle[Range[0, Length[blocks]-1],Flatten[#]&/@((If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand)],2];
vv=Select[vvv, Not[MemberQ[#[[2]], "NONE"]]&];
coors=(If[StringCases[#,_~~"e"->"0"]=={"0"}, 0, ToExpression[#]]&/@#)&/@StringSplit[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="position" &]&/@blocks)],","]]


make3Dmodel[id_]:=Module[{creaturefile, blocks, scale, childidCand, parents, vvv, vv, coors, spheres, l},
creaturefile=getCRT[id];
blocks=creaturefile[[2]][[3]][[3]][[3]];
scale=ToExpression[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="scale" &]&/@blocks)]];
childidCand=If[Length[#[[3]]]> 3,#[[3]][[4]][[3]], {"NONE"}] &/@blocks;
parents=Riffle[Range[0, Length[blocks]-1],Flatten[(If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand,1]];
vvv=Partition[Riffle[Range[0, Length[blocks]-1],Flatten[#]&/@((If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand)],2];
vv=Select[vvv, Not[MemberQ[#[[2]], "NONE"]]&];
coors=(If[StringCases[#,_~~"e"->"0"]=={"0"}, 0, ToExpression[#]]&/@#)&/@StringSplit[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="position" &]&/@blocks)],","];
spheres=Partition[Riffle[coors, scale],2];
l={coors[[#[[1]]+1]], coors[[#[[2]]+1]]}&/@Flatten[computeRules[#]&/@vv];
 Graphics3D[{ Red, Sphere[#[[1]], #[[2]]/20]&/@spheres, Blue, Thick, Line[#]&/@l}, Axes->True]]


getGeometrics[id_]:=Module[{coors, xMax, xMin, yMax, yMin, zMax, zMin, width, length, height},
coors=get3Dcoors[id];
xMax=Max[#[[1]]&/@coors];
xMin=Min[#[[1]]&/@coors];
yMax=Max[#[[2]]&/@coors];
yMin=Min[#[[2]]&/@coors];
zMax=Max[#[[3]]&/@coors];
zMin=Min[#[[3]]&/@coors];
height=zMax-zMin;
length=yMax-yMin;
width=xMax-xMin;
{width, length, height, (width+length)/height, (length + height)/width}]


getAssetsWguid[assets_, guid_]:=Flatten[Position[assets, #]&/@Select[assets, MemberQ[Complement[#], guid] &]]


getCreatureStats[id_, type_]:=getXMLdata[getXML[StringJoin["http://www.spore.com/rest/creature/",id]], type]


(* ::Subsubsection::Closed:: *)
(*Data*)


dta2=StringSplit[Import["http://www.spore.com/rest/assets/search/TOP_RATED/0/500/CREATURE", "Text"], {"<id>", "</id>"}];
itms3=dta2[[2*#]]&/@Range[500];


geom=getGeometrics[#]&/@itms3;


imgs=getImage[#]&/@itms3;


guds=getGuids[#]&/@itms3;


realGuds=makeNiceGuds[#]&/@guds;


allGuids=StringTake[#, {2,11}]&/@Complement[Flatten[guds]];


rigs=StringSplit[rigblocks, {"<id>", "</id>"}];
rigs=rigs[[2*#]]&/@Range[Length[rigs]/2];
names=StringSplit[rigblocks, {"<filename>", "</filename>"}];
names=names[[2*#]]&/@Range[Length[names]/2];
limbs=StringSplit[limblocks, {"<id>", "</id>"}];
limbs=limbs[[2*#]]&/@Range[Length[limbs]/2];
lnames=StringSplit[limblocks, {"<filename>", "</filename>"}];
lnames=lnames[[2*#]]&/@Range[Length[lnames]/2];
mapping=Partition[Riffle[rigs, names],2];
mappingRules=Rule[#[[1]], #[[2]]]&/@mapping;
lmapping=Partition[Riffle[limbs, lnames],2];
lmappingRules=Rule[#[[1]], #[[2]]]&/@lmapping;
masterMapping=Join[mappingRules, lmappingRules];


getPieces[num_]:={imgs[[num]],(StringTake[#, {2,11}]/.masterMapping/.imageMapping)&/@Complement[guds[[num]]]}


allGuids=#[[1]]&/@masterMapping;


allNames=#[[2]]&/@masterMapping;


allImages=Quiet[importRigblockImage[#]&/@allNames];


imageMapping=Rule[#[[1]], #[[2]]]&/@Partition[Riffle[allNames, allImages],2];


dta2=StringSplit[Import["http://www.spore.com/rest/assets/search/TOP_RATED/0/500/CREATURE", "Text"], {"<id>", "</id>"}];
itms3=dta2[[2*#]]&/@Range[500];
imgs=getImage[#]&/@itms3;
cute=getCreatureStats[#, "cuteness"][[1]][[3]][[1]]&/@itms3;
dat1=Partition[Flatten[Riffle[imgs,Partition[Flatten[Riffle[Round[ToExpression[#]/10]&/@mean, Round[ToExpression[#]/10]&/@cute]],2]]],3];
For[i=1, i<Length[dat1], i++;
If[dat1[[i]][[2]] > 0 && dat1[[i]][[3]] > 0 && dat1[[i]][[3]] < 101 && dat1[[i]][[2]] < 101 && tab[[dat1[[i]][[2]]]][[dat1[[i]][[3]]]][[1]]==".",
tab[[dat1[[i]][[2]]]][[dat1[[i]][[3]]]][[1]]=dat1[[i]][[1]]]];


dta2b=StringSplit[Import["http://www.spore.com/rest/assets/search/TOP_RATED_NEW/0/250/CREATURE", "Text"], {"<id>", "</id>"}];
itms3b=dta2b[[2*#]]&/@Range[250];
imgsb=getImage[#]&/@itms3b;
dat1b=Partition[Flatten[Riffle[imgsb,Partition[Flatten[Riffle[Round[ToExpression[#]/10]&/@meanb, Round[ToExpression[#]/10]&/@cuteb]],2]]],3];
cuteb=getCreatureStats[#, "cuteness"][[1]][[3]][[1]]&/@itms3b;
For[i=1, i<Length[dat1b], i++;
If[dat1b[[i]][[2]] > 0 && dat1b[[i]][[3]] > 0 && dat1b[[i]][[3]] < 101 && dat1b[[i]][[2]] < 101 && tab[[dat1b[[i]][[2]]]][[dat1b[[i]][[3]]]][[1]]==".",
tab[[dat1b[[i]][[2]]]][[dat1b[[i]][[3]]]][[1]]=dat1b[[i]][[1]]]];


costs=getCreatureStats[#, "cost"][[1]][[3]][[1]]&/@itms3;


height=getCreatureStats[#, "height"][[1]][[3]][[1]]&/@itms3;


mean=getCreatureStats[#, "meanness"][[1]][[3]][[1]]&/@itms3;


meanb=getCreatureStats[#, "meanness"][[1]][[3]][[1]]&/@itms3b;


bonecount=getCreatureStats[#, "bonecount"][[1]][[3]][[1]]&/@itms3;


health=getCreatureStats[#, "health"][[1]][[3]][[1]]&/@itms3;


(* ::Subsubsection::Closed:: *)
(*Sort by a Stat*)


TableForm[Partition[Sort[Partition[Riffle[imgs, ToExpression[#]&/@height], 2], #1[[2]] > #2[[2]] & ],18]]


(* ::Subsubsection::Closed:: *)
(*See Assets that have a Part*)


i=115;
test=getAssetsWguid[realGuds, allGuids[[i]]];
{allImages[[i]], imgs[[#]]&/@test}


i=144;
test=getAssetsWguid[realGuds, allGuids[[i]]];
{allImages[[i]], imgs[[#]]&/@test}


(* ::Subsubsection::Closed:: *)
(*See parts per Asset*)


getPieces[50]


(* ::Subsubsection::Closed:: *)
(*Simple & Complex*)


gudLength=Length[#]&/@guds;


ff=Sort[Partition[Riffle[imgs, gudLength],2], #1[[2]] > #2[[2]] &]


(* ::Subsubsection::Closed:: *)
(*Hot Dogs & Pancakes*)


dd=Partition[Riffle[imgs, geom],2];


#[[1]]&/@Sort[dd, (#1[[2]][[1]]+#1[[2]][[2]]-#1[[2]][[3]]) > (#2[[2]][[1]]+#2[[2]][[2]]-#2[[2]][[3]]) &]


(* ::Subsubsection::Closed:: *)
(*Correlation Table*)


correlateR[i_, j_]:=N[If[Length[getAssetsWguid[realGuds, allGuids[[i]]]] == 0, 0, Length[getAssetsWguid[realGuds[[#]]&/@getAssetsWguid[realGuds, allGuids[[i]]], allGuids[[j]]]]/Length[getAssetsWguid[realGuds, allGuids[[i]]]]]]


dita=Table[Table[correlateR[i, j], {i, 1, 20}], {j, 1, 20}];


Graphics[{Flatten[Table[Table[{ColorData["TemperatureMap"][dita[[i]][[j]]], Disk[{i,j}, 0.5]}, {i,1,20}], {j,1,20}]]}]


allImages[[1;;10]]


(* ::Subsection::Closed:: *)
(*Content*)


(* ::Subsubsection::Closed:: *)
(*Pollination*)


drawBar[x_, list_]:={Text[ToString[x], {x, -1}],Red, Rectangle[{x, 0}, {x+1, list[[1]][[2]]}], Orange, 
Rectangle[{x, list[[1]][[2]]}, {x+1, list[[1]][[2]]+list[[2]][[2]]}], Green,
Rectangle[{x, list[[1]][[2]]+list[[2]][[2]]}, {x+1, list[[1]][[2]]+list[[2]][[2]]+list[[3]][[2]]}] , Blue,
Rectangle[{x, list[[1]][[2]]+list[[2]][[2]]+list[[3]][[2]]}, {x+1, list[[1]][[2]]+list[[2]][[2]]+list[[3]][[2]]+list[[2]][[2]]}]}


news=Import["http://www.spore.com/rest/assets/search/NEWEST/0/200", "Text"];


create=StringSplit[news, {"<created>", "</created>"}];
created=StringSplit[create[[2*#]], ":"][[2;;3]]&/@Range[200];
createred={ToExpression[#[[1]]], Round[ToExpression[#[[2]]]]}&/@created;


type=StringSplit[news, {"<type>", "</type>"}];
types=type[[2*#]]&/@Range[200];


data=Partition[Riffle[ createred, types], 2];


recentSecond=data[[1]][[1]][[1]];


q=Select[data, #[[1]][[1]] == recentSecond-1 &];


determineUploadsAtSencond[second_]:={#, Count[#[[2]]&/@Select[q, #[[1]][[2]]==second &], #]}&/@{"CREATURE", "VEHICLE", "BUILDING", "UFO"}


pp={#,determineUploadsAtSencond[#]}&/@Range[60];


Graphics[drawBar[#[[1]],#[[2]]]&/@pp, ImageSize->1000]


jj={StringSplit[StringSplit[getXdat[#[[3]], "created"]," "][[2]], ":"][[1]], StringSplit[StringSplit[getXdat[#[[3]], "created"]," "][[2]], ":"][[2]], Round[ToExpression[StringSplit[StringSplit[getXdat[#[[3]], "created"]," "][[2]], ":"]][[3]]], getXdat[#[[3]], "type"]}&/@a;


determineUploadsAtSencond2[list_, second_]:={#, Count[#[[2]]&/@Select[list, #[[1]]==second &], #]}&/@{"CREATURE", "VEHICLE", "BUILDING", "UFO"}


makeList[items_]:=Module[{firstMoment},
firstMoment=AbsoluteTime[{2007,1,1,1,ToExpression[items[[1]][[1]][[1]]],ToExpression[items[[1]][[1]][[2]]]}];
{-AbsoluteTime[{2007,1,1,1,ToExpression[#[[1]][[1]]],ToExpression[#[[1]][[2]]]}]+firstMoment, #[[2]]}&/@items
]


ans=makeList[data];


mx=Max[#[[1]]&/@ans];


oo={#,determineUploadsAtSencond2[ans, #]}&/@Range[mx];


Graphics[drawBar[#[[1]],#[[2]]]&/@oo, ImageSize->1000]


(* ::Subsubsection::Closed:: *)
(*Distribution*)


trn=StringSplit[Import["http://www.spore.com/rest/assets/search/TOP_RATED_NEW/0/500", "Text"], {"<type>", "</type>"}];
topnew=trn[[2*#]]&/@Range[500];
tr=StringSplit[Import["http://www.spore.com/rest/assets/search/TOP_RATED/0/500", "Text"], {"<type>", "</type>"}];
top=tr[[2*#]]&/@Range[500];
ftrd=StringSplit[Import["http://www.spore.com/rest/assets/search/NEWEST/0/500", "Text"], {"<type>", "</type>"}];
feat=ftrd[[2*#]]&/@Range[500];


Manipulate[
creat=Count[topnew[[f;;b+1]], "CREATURE"];
vehic=Count[topnew[[f;;b+1]], "VEHICLE"];
buil=Count[topnew[[f;;b+1]], "BUILDING"];
ufo=Count[topnew[[f;;b+1]], "UFO"];
creatn=Count[top[[f;;b+1]], "CREATURE"];
vehicn=Count[top[[f;;b+1]], "VEHICLE"];
builn=Count[top[[f;;b+1]], "BUILDING"];
ufon=Count[top[[f;;b+1]], "UFO"];
creatr=Count[feat[[f;;b+1]], "CREATURE"];
vehicr=Count[feat[[f;;b+1]], "VEHICLE"];
builr=Count[feat[[f;;b+1]], "BUILDING"];
ufor=Count[feat[[f;;b+1]], "UFO"];
TableForm[{{PieChart[{creatr, vehicr, builr, ufor}, 
ChartLabels->{Style["Creature", Bold,24], Style["Building", Bold, 24], Style["Vehicle", Bold, 24], Style["UFO", Bold, 24]}, 
PlotLabel->Style["\nNewest", Bold, 28],
ImageSize->300, SectorOrigin->{Automatic,1}]},
{PieChart[{creatn, vehicn, builn, ufon}, 
ChartLabels->{Style["Creature", Bold,24], Style["Building", Bold, 24], Style["Vehicle", Bold, 24], Style["UFO", Bold, 24]}, 
PlotLabel->Style[StringJoin[ToString[f]," - ", ToString[b+1], "\nTop Rated"], Bold, 28],
ImageSize->300, SectorOrigin->{Automatic,1}]},
{PieChart[{creat, vehic, buil, ufo}, 
ChartLabels->{Style["Creature", Bold,24], Style["Building", Bold, 24], Style["Vehicle", Bold, 24], Style["UFO", Bold, 24]}, 
PlotLabel->Style[StringJoin["\nTop Rated Today"], Bold, 28],
ImageSize->300, SectorOrigin->{Automatic,1}]}}, TableDirections->Row], {{f, 1, "Start"}, 1,b,1}, {{b, 499, "End"},f,499,1}]


(* ::Subsubsection::Closed:: *)
(*Creature Comparer*)


makeBar[a_, b_, width_, height_]:=Graphics[{Blue, Rectangle[{0, 0}, {a*width/(a+b), height}], Red, Rectangle[{a*width/(a+b), 0}, {width, height}]}]


makeColorDisplay[id_]:=Module[{ci, primary, secondary, thirdary},
a=getCRT[id];
ci=#[[3]]&/@a[[2]][[3]][[2]][[3]][[8;;10]];
primary=ToExpression[StringSplit[ci[[1]][[1]], ","]];
secondary=ToExpression[StringSplit[ci[[2]][[1]], ","]];
thirdary=ToExpression[StringSplit[ci[[3]][[1]], ","]];
Graphics[{RGBColor[primary[[1]], primary[[2]], primary[[3]]], Disk[{0,0}, 1],
RGBColor[secondary[[1]], secondary[[2]], secondary[[3]]], Disk[{0,0},.6],
RGBColor[thirdary[[1]], thirdary[[2]], thirdary[[3]]], Disk[{0,0},.3]}]]


getCreatureCoords[id_]:=Module[{creaturefile, blocks, scale, childidCand, parents, vvv, vv, coors, spheres, l},
creaturefile=getCRT[id];
blocks=creaturefile[[2]][[3]][[3]][[3]];
scale=ToExpression[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="scale" &]&/@blocks)]];
childidCand=If[Length[#[[3]]]> 3,#[[3]][[4]][[3]], {"NONE"}] &/@blocks;
parents=Riffle[Range[0, Length[blocks]-1],Flatten[(If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand,1]];
vvv=Partition[Riffle[Range[0, Length[blocks]-1],Flatten[#]&/@((If[Length[#]>1,If[#[[1]]=="childid", #[[3]], "NONE"], "NONE"]&/@#)&/@childidCand)],2];
vv=Select[vvv, Not[MemberQ[#[[2]], "NONE"]]&];
coors=(If[StringCases[#,_~~"e"->"0"]=={"0"}, 0, ToExpression[#]]&/@#)&/@StringSplit[Flatten[#[[1]][[3]]&/@(Select[#[[3]][[2]][[3]], #[[1]]=="position" &]&/@blocks)],","];
spheres=Partition[Riffle[coors, scale],2];
l={coors[[#[[1]]+1]], coors[[#[[2]]+1]]}&/@Flatten[computeRules[#]&/@vv];
{l, spheres}]


A=myCreatures[[2]];
B=myCreatures[[4]];
infoA=getAssetInfo[A];
infoB=getAssetInfo[B];
statsA=getCreatureStats[A];
statsB=getCreatureStats[B];
corsA=getCreatureCoords[A];
corsB=getCreatureCoords[B];
frontA=Graphics[{EdgeForm[Thick], Blue, Disk[{#[[1]][[1]], #[[1]][[3]]}, #[[2]]/20]&/@corsA[[2]], Black, Line[{{#[[1]][[1]], #[[1]][[3]]}, {#[[2]][[1]], #[[2]][[3]]}}]&/@corsA[[1]]}];
frontB=Graphics[{EdgeForm[Thick], Red, Disk[{#[[1]][[1]], #[[1]][[3]]}, #[[2]]/20]&/@corsB[[2]], Black, Line[{{#[[1]][[1]], #[[1]][[3]]}, {#[[2]][[1]], #[[2]][[3]]}}]&/@corsB[[1]]}];
sideA=Graphics[{ EdgeForm[Thick], Blue, Disk[{#[[1]][[2]], #[[1]][[3]]}, #[[2]]/20]&/@corsA[[2]], Black, Line[{{#[[1]][[2]], #[[1]][[3]]}, {#[[2]][[2]], #[[2]][[3]]}}]&/@corsA[[1]]}];
sideB=Graphics[{ EdgeForm[Thick], Red, Disk[{#[[1]][[2]], #[[1]][[3]]}, #[[2]]/20]&/@corsB[[2]], Black, Line[{{#[[1]][[2]], #[[1]][[3]]}, {#[[2]][[2]], #[[2]][[3]]}}]&/@corsB[[1]]}];
colorsA=makeColorDisplay[A];
colorsB=makeColorDisplay[B];
Graphics[{
Text[Style[ToUpperCase[getXMLdata[infoA, "name"][[1]][[3]][[1]]], 18, Blue], {-4.5,5}, Left], 
Text[Style[ToExpression[Round[ToExpression[getXMLdata[infoA, "rating"][[1]][[3]][[1]]],0.1]], 24, Black], {-4.5,1}, Left],
Inset[getImage[A], {-3,3}, Automatic, {3,3}],
Text[Style[ToUpperCase[getXMLdata[infoB, "name"][[1]][[3]][[1]]], 18, Red], {7.5,5}, Right], 
Text[Style[ToExpression[Round[ToExpression[getXMLdata[infoB, "rating"][[1]][[3]][[1]]],0.1]], 24, Black], {7.5,1}, Right],
Inset[getImage[B], {6,3}, Automatic, {3,3}],
Inset[colorsA, {0,3}, Automatic, {2,2}], Inset[colorsB, {3,3}, Automatic, {2,2}],
Inset[sideA, {0,0}, Automatic, {3,3}], Inset[sideB, {3,0}, Automatic, {3,3}],
Text[Style["cost", 14, Black], {-1.35,-2}, Left],
Inset[makeBar[ToExpression[getXMLvalue[statsA, "cost"]], ToExpression[getXMLvalue[statsB, "cost"]], 100, 5], {1.5,-2.5}, Automatic, {6,1}],
Text[Style["health", 14, Black], {-1.35,-3}, Left],
Inset[makeBar[ToExpression[getXMLvalue[statsA, "health"]], ToExpression[getXMLvalue[statsB, "health"]], 100, 5], {1.5,-3.5}, Automatic, {6,1}],
Text[Style["height", 14, Black], {-1.35,-4}, Left],
Inset[makeBar[ToExpression[getXMLvalue[statsA, "height"]], ToExpression[getXMLvalue[statsB, "height"]], 100, 5], {1.5,-4.5}, Automatic, {6,1}]}, ImageSize->500]
